@@ -41,7 +41,7 @@ and workspace.
 """
 
 # Set version number
-__version__ = "4.10.2"
+__version__ = "4.11.0"
 
 import os
 import sys
@@ -58,11 +58,11 @@ if getattr(sys, "frozen", False):
     app_dir = os.path.dirname(sys.executable)
     # if sys.platform.startswith('win'):
     #     os.environ['QT_QPA_PLATFORM_PLUGIN_PATH'] = app_dir
-    if sys.platform.startswith("linux"):
-        # os.environ['QT_XKB_CONFIG_ROOT'] = '.'
-        os.environ["FONTCONFIG_FILE"] = os.path.join(
-            app_dir, "source/pyzo/resources", "fonts/linux_fonts.conf"
-        )
+    # if sys.platform.startswith("linux"):
+    #    # os.environ['QT_XKB_CONFIG_ROOT'] = '.'
+    #    os.environ["FONTCONFIG_FILE"] = os.path.join(
+    #        app_dir, "source/pyzo/resources", "fonts/linux_fonts.conf"
+    #    )
 
 # Automatically scale along on HDPI displays. See issue #531 and e.g.
 # https://wiki.archlinux.org/index.php/HiDPI#Qt_5
@@ -96,11 +96,15 @@ from pyzo.util.qt import QtCore, QtGui, QtWidgets
 
 # Enable high-res displays
 try:
-    ctypes.windll.shcore.SetProcessDpiAwareness(True)
+    ctypes.windll.shcore.SetProcessDpiAwareness(1)
+    ctypes.windll.shcore.SetProcessDpiAwareness(2)
 except Exception:
-    pass
-QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
-QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
+    pass  # fail on non-windows
+try:
+    QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
+    QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
+except Exception:
+    pass  # fail on older Qt's
 
 # Import language/translation tools
 from pyzo.util._locale import translate, setLanguage  # noqa
@@ -112,7 +116,7 @@ os.environ["PYZO_QTLIB"] = "PyQt4" if _is_pyqt4 else "PySide"
 
 
 class MyApp(QtWidgets.QApplication):
-    """ So we an open .py files on OSX.
+    """So we an open .py files on OSX.
     OSX is smart enough to call this on the existing process.
     """
 
@@ -155,7 +159,7 @@ sys.excepthook = pyzo_excepthook
 
 
 def getResourceDirs():
-    """ getResourceDirs()
+    """getResourceDirs()
     Get the directories to the resources: (pyzoDir, appDataDir, appConfigDir).
     Also makes sure that the appDataDir has a "tools" directory and
     a style file.
@@ -180,7 +184,7 @@ def getResourceDirs():
 
 
 def resetConfig(preserveState=True):
-    """ resetConfig()
+    """resetConfig()
     Deletes the config file to revert to default and prevent Pyzo from storing
     its config on the next shutdown.
     """
@@ -220,7 +224,7 @@ def loadThemes():
 
 
 def loadConfig(defaultsOnly=False):
-    """ loadConfig(defaultsOnly=False)
+    """loadConfig(defaultsOnly=False)
     Load default and site-wide configuration file(s) and that of the user (if it exists).
     Any missing fields in the user config are set to the defaults.
     """
@@ -269,7 +273,7 @@ def loadConfig(defaultsOnly=False):
 
 
 def saveConfig():
-    """ saveConfig()
+    """saveConfig()
     Save all configureations to file.
     """
 
@@ -287,8 +291,7 @@ def saveConfig():
 
 
 def start():
-    """ Run Pyzo.
-    """
+    """Run Pyzo."""
 
     # Do some imports
     from pyzo.core import pyzoLogging  # noqa - to start logging asap
